@@ -38,6 +38,10 @@ function _aws_cdk_aws_athena_CfnWorkGroupProps(p) {
 }
 function _aws_cdk_aws_athena_CfnWorkGroup(p) {
 }
+function _aws_cdk_aws_athena_CfnWorkGroup_AclConfigurationProperty(p) {
+}
+function _aws_cdk_aws_athena_CfnWorkGroup_CustomerContentEncryptionConfigurationProperty(p) {
+}
 function _aws_cdk_aws_athena_CfnWorkGroup_EncryptionConfigurationProperty(p) {
 }
 function _aws_cdk_aws_athena_CfnWorkGroup_EngineVersionProperty(p) {
@@ -82,4 +86,4 @@ class DeprecationError extends Error {
         });
     }
 }
-module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_athena_CfnDataCatalogProps, _aws_cdk_aws_athena_CfnDataCatalog, _aws_cdk_aws_athena_CfnNamedQueryProps, _aws_cdk_aws_athena_CfnNamedQuery, _aws_cdk_aws_athena_CfnPreparedStatementProps, _aws_cdk_aws_athena_CfnPreparedStatement, _aws_cdk_aws_athena_CfnWorkGroupProps, _aws_cdk_aws_athena_CfnWorkGroup, _aws_cdk_aws_athena_CfnWorkGroup_EncryptionConfigurationProperty, _aws_cdk_aws_athena_CfnWorkGroup_EngineVersionProperty, _aws_cdk_aws_athena_CfnWorkGroup_ResultConfigurationProperty, _aws_cdk_aws_athena_CfnWorkGroup_WorkGroupConfigurationProperty };
+module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_athena_CfnDataCatalogProps, _aws_cdk_aws_athena_CfnDataCatalog, _aws_cdk_aws_athena_CfnNamedQueryProps, _aws_cdk_aws_athena_CfnNamedQuery, _aws_cdk_aws_athena_CfnPreparedStatementProps, _aws_cdk_aws_athena_CfnPreparedStatement, _aws_cdk_aws_athena_CfnWorkGroupProps, _aws_cdk_aws_athena_CfnWorkGroup, _aws_cdk_aws_athena_CfnWorkGroup_AclConfigurationProperty, _aws_cdk_aws_athena_CfnWorkGroup_CustomerContentEncryptionConfigurationProperty, _aws_cdk_aws_athena_CfnWorkGroup_EncryptionConfigurationProperty, _aws_cdk_aws_athena_CfnWorkGroup_EngineVersionProperty, _aws_cdk_aws_athena_CfnWorkGroup_ResultConfigurationProperty, _aws_cdk_aws_athena_CfnWorkGroup_WorkGroupConfigurationProperty };
